pub trait AttachedValidator {
// Required method
fn required_objects(&self) -> Vec<RequiredObject>;
// Provided method
fn validate(&self, ctx: &mut ValidationContext<'_>) -> ValidationReport { ... }
}Expand description
Attached-mode validation: check that externally managed resources exist.
Attached validation must never create, alter, or drop datastore schema.
Required Methods
Sourcefn required_objects(&self) -> Vec<RequiredObject>
fn required_objects(&self) -> Vec<RequiredObject>
Declare the objects this consumer requires.
Provided Methods
Sourcefn validate(&self, ctx: &mut ValidationContext<'_>) -> ValidationReport
fn validate(&self, ctx: &mut ValidationContext<'_>) -> ValidationReport
Run all validators and return a report of present and missing objects.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".